==> alg-alg-2.23.89-sources.jar: cn/com/duiba/nezha/alg/alg/adx/rcmd2/Model.java <==
package cn.com.duiba.nezha.alg.alg.adx.rcmd2;

import cn.com.duiba.nezha.alg.feature.vo.FeatureMapDo;
import cn.com.duiba.nezha.alg.model.IModel;
import cn.com.duiba.nezha.alg.model.tf.LocalTFModel;
import com.alibaba.fastjson.JSONObject;
import lombok.Data;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.HashMap;
import java.util.Map;

@Data
public class Model {
    private static final Logger logger = LoggerFactory.getLogger(Model.class);

    private IModel ctrModel;
    private IModel launchPvCoder;
    private IModel ARPUCoder;
    private LocalTFModel launchPvTFModel;  // launchPvCoder对应的TF model
    private LocalTFModel arpuTFModel;   // ARPUCoder对应的TF model
    private LocalTFModel localTFModel;

    public Map<FeatureIndex, Double> predictCtr(Map<FeatureIndex, FeatureMapDo> featureMap) throws Exception {
        try {
            Map<FeatureIndex, Double> ret;
            ret = ctrModel.predictsNew(featureMap);
            return ret;
        }
        catch (Exception e) {
            logger.error("AdxRecommend.predictCtr", e);
        }
        return null;
    }

    public Map<FeatureIndex, Double> predictLaunchPv(Map<FeatureIndex, FeatureMapDo> featureMap) throws Exception {
        try {
            Map<FeatureIndex, Double> ret;
//        logger.info("featureMap{}, launchPvTFModel{}", JSONObject.toJSON(featureMap), JSONObject.toJSON(launchPvTFModel));
            ret = launchPvCoder.predictWithLocalTFNew(featureMap, launchPvTFModel);
            return ret;
        }
        catch (Exception e) {
            logger.error("AdxRecommend.predictLaunchPv", e);
        }
        return null;
    }

    public Map<FeatureIndex, Double> predictARPU(Map<FeatureIndex, FeatureMapDo> featureMap) throws Exception {
        try {
            Map<FeatureIndex, Double> ret;
            ret = ARPUCoder.predictWithLocalTFNew(featureMap, arpuTFModel);
            return ret;
        }
        catch (Exception e) {
            logger.error("AdxRecommend.predictARPU", e);
        }
        return null;
    }


}

==> alg-alg-2.24.12-sources.jar: cn/com/duiba/nezha/alg/alg/adx/rcmd2/Model.java <==
package cn.com.duiba.nezha.alg.alg.adx.rcmd2;

import cn.com.duiba.nezha.alg.feature.vo.FeatureMapDo;
import cn.com.duiba.nezha.alg.model.IModel;
import cn.com.duiba.nezha.alg.model.tf.LocalTFModel;
import com.alibaba.fastjson.JSONObject;
import lombok.Data;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.HashMap;
import java.util.Map;

@Data
public class Model {
    private static final Logger logger = LoggerFactory.getLogger(Model.class);

    private IModel ctrModel;
    private IModel launchPvCoder;
    private IModel ARPUCoder;
    private LocalTFModel launchPvTFModel;  // launchPvCoder对应的TF model
    private LocalTFModel arpuTFModel;   // ARPUCoder对应的TF model
    private LocalTFModel localTFModel;

    public Map<FeatureIndex, Double> predictCtr(Map<FeatureIndex, FeatureMapDo> featureMap) throws Exception {
        try {
            Map<FeatureIndex, Double> ret;
            ret = ctrModel.predictsNew(featureMap);
            return ret;
        }
        catch (Exception e) {
            logger.error("AdxRecommend.predictCtr error{} ctrModel{}", e, ctrModel);
        }
        return null;
    }

    public Map<FeatureIndex, Double> predictLaunchPv(Map<FeatureIndex, FeatureMapDo> featureMap) throws Exception {
        try {
            Map<FeatureIndex, Double> ret;
//        logger.info("featureMap{}, launchPvTFModel{}", JSONObject.toJSON(featureMap), JSONObject.toJSON(launchPvTFModel));
            ret = launchPvCoder.predictWithLocalTFNew(featureMap, launchPvTFModel);
            return ret;
        }
        catch (Exception e) {
            logger.error("AdxRecommend.predictLaunchPv error{}, launchPvCoder{}, launchPvTFModel{}", e, launchPvCoder, launchPvTFModel);
        }
        return null;
    }

    public Map<FeatureIndex, Double> predictARPU(Map<FeatureIndex, FeatureMapDo> featureMap) throws Exception {
        try {
            Map<FeatureIndex, Double> ret;
            ret = ARPUCoder.predictWithLocalTFNew(featureMap, arpuTFModel);
            return ret;
        }
        catch (Exception e) {
            logger.error("AdxRecommend.predictARPU error{}, ARPUCoder{}, arpuTFModel{}", e, ARPUCoder, arpuTFModel);
        }
        return null;
    }


}
